"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_confirmed_transactions_by_address_ribsd2_vin_inner_script_sig import ListConfirmedTransactionsByAddressRIBSD2VinInnerScriptSig
globals()['ListConfirmedTransactionsByAddressRIBSD2VinInnerScriptSig'] = ListConfirmedTransactionsByAddressRIBSD2VinInnerScriptSig
from cryptoapis.model.list_all_unconfirmed_transactions_ribsd2_vin_inner import ListAllUnconfirmedTransactionsRIBSD2VinInner


class TestListAllUnconfirmedTransactionsRIBSD2VinInner(unittest.TestCase):
    """ListAllUnconfirmedTransactionsRIBSD2VinInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListAllUnconfirmedTransactionsRIBSD2VinInner(self):
        """Test ListAllUnconfirmedTransactionsRIBSD2VinInner"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListAllUnconfirmedTransactionsRIBSD2VinInner()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
