"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsb import GetBlockDetailsByBlockHeightFromCallbackRIBSB
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsbc import GetBlockDetailsByBlockHeightFromCallbackRIBSBC
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsbsc import GetBlockDetailsByBlockHeightFromCallbackRIBSBSC
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsd import GetBlockDetailsByBlockHeightFromCallbackRIBSD
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsd2 import GetBlockDetailsByBlockHeightFromCallbackRIBSD2
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribse import GetBlockDetailsByBlockHeightFromCallbackRIBSE
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsec import GetBlockDetailsByBlockHeightFromCallbackRIBSEC
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsl import GetBlockDetailsByBlockHeightFromCallbackRIBSL
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsx import GetBlockDetailsByBlockHeightFromCallbackRIBSX
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsz import GetBlockDetailsByBlockHeightFromCallbackRIBSZ
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribsz2 import GetBlockDetailsByBlockHeightFromCallbackRIBSZ2
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_coins import GetLatestMinedXRPRippleBlockRITotalCoins
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_fees import GetLatestMinedXRPRippleBlockRITotalFees
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSB'] = GetBlockDetailsByBlockHeightFromCallbackRIBSB
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSBC'] = GetBlockDetailsByBlockHeightFromCallbackRIBSBC
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSBSC'] = GetBlockDetailsByBlockHeightFromCallbackRIBSBSC
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSD'] = GetBlockDetailsByBlockHeightFromCallbackRIBSD
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSD2'] = GetBlockDetailsByBlockHeightFromCallbackRIBSD2
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSE'] = GetBlockDetailsByBlockHeightFromCallbackRIBSE
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSEC'] = GetBlockDetailsByBlockHeightFromCallbackRIBSEC
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSL'] = GetBlockDetailsByBlockHeightFromCallbackRIBSL
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSX'] = GetBlockDetailsByBlockHeightFromCallbackRIBSX
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSZ'] = GetBlockDetailsByBlockHeightFromCallbackRIBSZ
globals()['GetBlockDetailsByBlockHeightFromCallbackRIBSZ2'] = GetBlockDetailsByBlockHeightFromCallbackRIBSZ2
globals()['GetLatestMinedXRPRippleBlockRITotalCoins'] = GetLatestMinedXRPRippleBlockRITotalCoins
globals()['GetLatestMinedXRPRippleBlockRITotalFees'] = GetLatestMinedXRPRippleBlockRITotalFees
from cryptoapis.model.get_block_details_by_block_height_from_callback_ribs import GetBlockDetailsByBlockHeightFromCallbackRIBS


class TestGetBlockDetailsByBlockHeightFromCallbackRIBS(unittest.TestCase):
    """GetBlockDetailsByBlockHeightFromCallbackRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHeightFromCallbackRIBS(self):
        """Test GetBlockDetailsByBlockHeightFromCallbackRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHeightFromCallbackRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
