"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.address_tokens_transaction_confirmed_data_item_mined_in_block import AddressTokensTransactionConfirmedDataItemMinedInBlock
from cryptoapis.model.confirmed_tokens_transaction_for_certain_amount_or_higher_token import ConfirmedTokensTransactionForCertainAmountOrHigherToken
globals()['AddressTokensTransactionConfirmedDataItemMinedInBlock'] = AddressTokensTransactionConfirmedDataItemMinedInBlock
globals()['ConfirmedTokensTransactionForCertainAmountOrHigherToken'] = ConfirmedTokensTransactionForCertainAmountOrHigherToken
from cryptoapis.model.confirmed_tokens_transaction_for_certain_amount_or_higher_data_item import ConfirmedTokensTransactionForCertainAmountOrHigherDataItem


class TestConfirmedTokensTransactionForCertainAmountOrHigherDataItem(unittest.TestCase):
    """ConfirmedTokensTransactionForCertainAmountOrHigherDataItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConfirmedTokensTransactionForCertainAmountOrHigherDataItem(self):
        """Test ConfirmedTokensTransactionForCertainAmountOrHigherDataItem"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConfirmedTokensTransactionForCertainAmountOrHigherDataItem()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
