"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_all_assets_from_all_wallets_ri_coins_inner import ListAllAssetsFromAllWalletsRICoinsInner
from cryptoapis.model.list_all_assets_from_all_wallets_ri_fungible_tokens_inner import ListAllAssetsFromAllWalletsRIFungibleTokensInner
from cryptoapis.model.list_all_assets_from_all_wallets_ri_non_fungible_tokens_inner import ListAllAssetsFromAllWalletsRINonFungibleTokensInner
globals()['ListAllAssetsFromAllWalletsRICoinsInner'] = ListAllAssetsFromAllWalletsRICoinsInner
globals()['ListAllAssetsFromAllWalletsRIFungibleTokensInner'] = ListAllAssetsFromAllWalletsRIFungibleTokensInner
globals()['ListAllAssetsFromAllWalletsRINonFungibleTokensInner'] = ListAllAssetsFromAllWalletsRINonFungibleTokensInner
from cryptoapis.model.list_all_assets_from_all_wallets_ri import ListAllAssetsFromAllWalletsRI


class TestListAllAssetsFromAllWalletsRI(unittest.TestCase):
    """ListAllAssetsFromAllWalletsRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListAllAssetsFromAllWalletsRI(self):
        """Test ListAllAssetsFromAllWalletsRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListAllAssetsFromAllWalletsRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
