"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vin_inner import GetTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc_gas_price import ListConfirmedTransactionsByAddressRIBSBSCGasPrice
from cryptoapis.model.list_confirmed_transactions_by_address_ribszv_join_split_inner import ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsb import ListUnconfirmedTransactionsByAddressRIBSB
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsbc import ListUnconfirmedTransactionsByAddressRIBSBC
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsbsc import ListUnconfirmedTransactionsByAddressRIBSBSC
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd import ListUnconfirmedTransactionsByAddressRIBSD
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd2 import ListUnconfirmedTransactionsByAddressRIBSD2
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribse import ListUnconfirmedTransactionsByAddressRIBSE
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsec import ListUnconfirmedTransactionsByAddressRIBSEC
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsec_fee import ListUnconfirmedTransactionsByAddressRIBSECFee
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsl import ListUnconfirmedTransactionsByAddressRIBSL
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsz import ListUnconfirmedTransactionsByAddressRIBSZ
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVinInner'] = GetTransactionDetailsByTransactionIDRIBSZVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListConfirmedTransactionsByAddressRIBSBSCGasPrice'] = ListConfirmedTransactionsByAddressRIBSBSCGasPrice
globals()['ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner'] = ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['ListUnconfirmedTransactionsByAddressRIBSB'] = ListUnconfirmedTransactionsByAddressRIBSB
globals()['ListUnconfirmedTransactionsByAddressRIBSBC'] = ListUnconfirmedTransactionsByAddressRIBSBC
globals()['ListUnconfirmedTransactionsByAddressRIBSBSC'] = ListUnconfirmedTransactionsByAddressRIBSBSC
globals()['ListUnconfirmedTransactionsByAddressRIBSD'] = ListUnconfirmedTransactionsByAddressRIBSD
globals()['ListUnconfirmedTransactionsByAddressRIBSD2'] = ListUnconfirmedTransactionsByAddressRIBSD2
globals()['ListUnconfirmedTransactionsByAddressRIBSE'] = ListUnconfirmedTransactionsByAddressRIBSE
globals()['ListUnconfirmedTransactionsByAddressRIBSEC'] = ListUnconfirmedTransactionsByAddressRIBSEC
globals()['ListUnconfirmedTransactionsByAddressRIBSECFee'] = ListUnconfirmedTransactionsByAddressRIBSECFee
globals()['ListUnconfirmedTransactionsByAddressRIBSL'] = ListUnconfirmedTransactionsByAddressRIBSL
globals()['ListUnconfirmedTransactionsByAddressRIBSZ'] = ListUnconfirmedTransactionsByAddressRIBSZ
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribs import ListUnconfirmedTransactionsByAddressRIBS


class TestListUnconfirmedTransactionsByAddressRIBS(unittest.TestCase):
    """ListUnconfirmedTransactionsByAddressRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListUnconfirmedTransactionsByAddressRIBS(self):
        """Test ListUnconfirmedTransactionsByAddressRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListUnconfirmedTransactionsByAddressRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
