"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsb import GetBlockDetailsByBlockHashFromCallbackRIBSB
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsbc import GetBlockDetailsByBlockHashFromCallbackRIBSBC
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsbsc import GetBlockDetailsByBlockHashFromCallbackRIBSBSC
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsd import GetBlockDetailsByBlockHashFromCallbackRIBSD
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsd2 import GetBlockDetailsByBlockHashFromCallbackRIBSD2
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribse import GetBlockDetailsByBlockHashFromCallbackRIBSE
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsec import GetBlockDetailsByBlockHashFromCallbackRIBSEC
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsl import GetBlockDetailsByBlockHashFromCallbackRIBSL
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsx import GetBlockDetailsByBlockHashFromCallbackRIBSX
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsz import GetBlockDetailsByBlockHashFromCallbackRIBSZ
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribsz2 import GetBlockDetailsByBlockHashFromCallbackRIBSZ2
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_coins import GetLatestMinedXRPRippleBlockRITotalCoins
from cryptoapis.model.get_latest_mined_xrp_ripple_block_ri_total_fees import GetLatestMinedXRPRippleBlockRITotalFees
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSB'] = GetBlockDetailsByBlockHashFromCallbackRIBSB
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSBC'] = GetBlockDetailsByBlockHashFromCallbackRIBSBC
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSBSC'] = GetBlockDetailsByBlockHashFromCallbackRIBSBSC
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSD'] = GetBlockDetailsByBlockHashFromCallbackRIBSD
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSD2'] = GetBlockDetailsByBlockHashFromCallbackRIBSD2
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSE'] = GetBlockDetailsByBlockHashFromCallbackRIBSE
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSEC'] = GetBlockDetailsByBlockHashFromCallbackRIBSEC
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSL'] = GetBlockDetailsByBlockHashFromCallbackRIBSL
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSX'] = GetBlockDetailsByBlockHashFromCallbackRIBSX
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSZ'] = GetBlockDetailsByBlockHashFromCallbackRIBSZ
globals()['GetBlockDetailsByBlockHashFromCallbackRIBSZ2'] = GetBlockDetailsByBlockHashFromCallbackRIBSZ2
globals()['GetLatestMinedXRPRippleBlockRITotalCoins'] = GetLatestMinedXRPRippleBlockRITotalCoins
globals()['GetLatestMinedXRPRippleBlockRITotalFees'] = GetLatestMinedXRPRippleBlockRITotalFees
from cryptoapis.model.get_block_details_by_block_hash_from_callback_ribs import GetBlockDetailsByBlockHashFromCallbackRIBS


class TestGetBlockDetailsByBlockHashFromCallbackRIBS(unittest.TestCase):
    """GetBlockDetailsByBlockHashFromCallbackRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHashFromCallbackRIBS(self):
        """Test GetBlockDetailsByBlockHashFromCallbackRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHashFromCallbackRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
