"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_recipients_inner import GetXRPRippleTransactionDetailsByTransactionIDRIRecipientsInner
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_senders_inner import GetXRPRippleTransactionDetailsByTransactionIDRISendersInner
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_fee import ListXRPRippleTransactionsByAddressRIFee
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_offer import ListXRPRippleTransactionsByAddressRIOffer
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_receive import ListXRPRippleTransactionsByAddressRIReceive
from cryptoapis.model.list_xrp_ripple_transactions_by_address_ri_value import ListXRPRippleTransactionsByAddressRIValue
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIRecipientsInner'] = GetXRPRippleTransactionDetailsByTransactionIDRIRecipientsInner
globals()['GetXRPRippleTransactionDetailsByTransactionIDRISendersInner'] = GetXRPRippleTransactionDetailsByTransactionIDRISendersInner
globals()['ListXRPRippleTransactionsByAddressRIFee'] = ListXRPRippleTransactionsByAddressRIFee
globals()['ListXRPRippleTransactionsByAddressRIOffer'] = ListXRPRippleTransactionsByAddressRIOffer
globals()['ListXRPRippleTransactionsByAddressRIReceive'] = ListXRPRippleTransactionsByAddressRIReceive
globals()['ListXRPRippleTransactionsByAddressRIValue'] = ListXRPRippleTransactionsByAddressRIValue
from cryptoapis.model.list_xrp_ripple_transactions_by_address_and_time_range_ri import ListXRPRippleTransactionsByAddressAndTimeRangeRI


class TestListXRPRippleTransactionsByAddressAndTimeRangeRI(unittest.TestCase):
    """ListXRPRippleTransactionsByAddressAndTimeRangeRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListXRPRippleTransactionsByAddressAndTimeRangeRI(self):
        """Test ListXRPRippleTransactionsByAddressAndTimeRangeRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListXRPRippleTransactionsByAddressAndTimeRangeRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
