"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_vin_inner import GetTransactionDetailsByTransactionIDRIBSD2VinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_vout_inner import GetTransactionDetailsByTransactionIDRIBSD2VoutInner
globals()['GetTransactionDetailsByTransactionIDRIBSD2VinInner'] = GetTransactionDetailsByTransactionIDRIBSD2VinInner
globals()['GetTransactionDetailsByTransactionIDRIBSD2VoutInner'] = GetTransactionDetailsByTransactionIDRIBSD2VoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2 import GetTransactionDetailsByTransactionIDRIBSD2


class TestGetTransactionDetailsByTransactionIDRIBSD2(unittest.TestCase):
    """GetTransactionDetailsByTransactionIDRIBSD2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTransactionDetailsByTransactionIDRIBSD2(self):
        """Test GetTransactionDetailsByTransactionIDRIBSD2"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTransactionDetailsByTransactionIDRIBSD2()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
