"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.new_confirmed_token_transactions_for_specific_amount_e403 import NewConfirmedTokenTransactionsForSpecificAmountE403
globals()['NewConfirmedTokenTransactionsForSpecificAmountE403'] = NewConfirmedTokenTransactionsForSpecificAmountE403
from cryptoapis.model.new_confirmed_token_transactions_for_specific_amount403_response import NewConfirmedTokenTransactionsForSpecificAmount403Response


class TestNewConfirmedTokenTransactionsForSpecificAmount403Response(unittest.TestCase):
    """NewConfirmedTokenTransactionsForSpecificAmount403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNewConfirmedTokenTransactionsForSpecificAmount403Response(self):
        """Test NewConfirmedTokenTransactionsForSpecificAmount403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NewConfirmedTokenTransactionsForSpecificAmount403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
