"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsb import GetTransactionDetailsByTransactionIDFromCallbackRIBSB
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsbc import GetTransactionDetailsByTransactionIDFromCallbackRIBSBC
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsbsc import GetTransactionDetailsByTransactionIDFromCallbackRIBSBSC
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsd import GetTransactionDetailsByTransactionIDFromCallbackRIBSD
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsd2 import GetTransactionDetailsByTransactionIDFromCallbackRIBSD2
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribse import GetTransactionDetailsByTransactionIDFromCallbackRIBSE
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsec import GetTransactionDetailsByTransactionIDFromCallbackRIBSEC
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsl import GetTransactionDetailsByTransactionIDFromCallbackRIBSL
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsx import GetTransactionDetailsByTransactionIDFromCallbackRIBSX
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsx_value import GetTransactionDetailsByTransactionIDFromCallbackRIBSXValue
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsz import GetTransactionDetailsByTransactionIDFromCallbackRIBSZ
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsz2 import GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsz2_gas_price import GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2GasPrice
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vin_inner import GetTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_join_split_inner import GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_offer import GetXRPRippleTransactionDetailsByTransactionIDRIOffer
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_receive import GetXRPRippleTransactionDetailsByTransactionIDRIReceive
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSB'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSB
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSBC'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSBC
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSBSC'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSBSC
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSD'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSD
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSD2'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSD2
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSE'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSE
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSEC'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSEC
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSL'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSL
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSX'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSX
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSXValue'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSXValue
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSZ'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSZ
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2GasPrice'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2GasPrice
globals()['GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner'] = GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVinInner'] = GetTransactionDetailsByTransactionIDRIBSZVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIOffer'] = GetXRPRippleTransactionDetailsByTransactionIDRIOffer
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIReceive'] = GetXRPRippleTransactionDetailsByTransactionIDRIReceive
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribs import GetTransactionDetailsByTransactionIDFromCallbackRIBS


class TestGetTransactionDetailsByTransactionIDFromCallbackRIBS(unittest.TestCase):
    """GetTransactionDetailsByTransactionIDFromCallbackRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTransactionDetailsByTransactionIDFromCallbackRIBS(self):
        """Test GetTransactionDetailsByTransactionIDFromCallbackRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTransactionDetailsByTransactionIDFromCallbackRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
