"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_address_details_from_callback_ri_total_received import GetAddressDetailsFromCallbackRITotalReceived
from cryptoapis.model.get_address_details_from_callback_ri_total_spent import GetAddressDetailsFromCallbackRITotalSpent
from cryptoapis.model.get_address_details_ri_confirmed_balance import GetAddressDetailsRIConfirmedBalance
globals()['GetAddressDetailsFromCallbackRITotalReceived'] = GetAddressDetailsFromCallbackRITotalReceived
globals()['GetAddressDetailsFromCallbackRITotalSpent'] = GetAddressDetailsFromCallbackRITotalSpent
globals()['GetAddressDetailsRIConfirmedBalance'] = GetAddressDetailsRIConfirmedBalance
from cryptoapis.model.get_address_details_from_callback_ri import GetAddressDetailsFromCallbackRI


class TestGetAddressDetailsFromCallbackRI(unittest.TestCase):
    """GetAddressDetailsFromCallbackRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetAddressDetailsFromCallbackRI(self):
        """Test GetAddressDetailsFromCallbackRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetAddressDetailsFromCallbackRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
