"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_xrp_ripple_transactions_by_address_and_time_range_e401 import ListXRPRippleTransactionsByAddressAndTimeRangeE401
globals()['ListXRPRippleTransactionsByAddressAndTimeRangeE401'] = ListXRPRippleTransactionsByAddressAndTimeRangeE401
from cryptoapis.model.list_xrp_ripple_transactions_by_address_and_time_range401_response import ListXRPRippleTransactionsByAddressAndTimeRange401Response


class TestListXRPRippleTransactionsByAddressAndTimeRange401Response(unittest.TestCase):
    """ListXRPRippleTransactionsByAddressAndTimeRange401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListXRPRippleTransactionsByAddressAndTimeRange401Response(self):
        """Test ListXRPRippleTransactionsByAddressAndTimeRange401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListXRPRippleTransactionsByAddressAndTimeRange401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
