"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_last_mined_block_ribsb import GetLastMinedBlockRIBSB
from cryptoapis.model.get_last_mined_block_ribsbc import GetLastMinedBlockRIBSBC
from cryptoapis.model.get_last_mined_block_ribsbsc import GetLastMinedBlockRIBSBSC
from cryptoapis.model.get_last_mined_block_ribsd import GetLastMinedBlockRIBSD
from cryptoapis.model.get_last_mined_block_ribsd2 import GetLastMinedBlockRIBSD2
from cryptoapis.model.get_last_mined_block_ribse import GetLastMinedBlockRIBSE
from cryptoapis.model.get_last_mined_block_ribsec import GetLastMinedBlockRIBSEC
from cryptoapis.model.get_last_mined_block_ribsl import GetLastMinedBlockRIBSL
from cryptoapis.model.get_last_mined_block_ribsz import GetLastMinedBlockRIBSZ
globals()['GetLastMinedBlockRIBSB'] = GetLastMinedBlockRIBSB
globals()['GetLastMinedBlockRIBSBC'] = GetLastMinedBlockRIBSBC
globals()['GetLastMinedBlockRIBSBSC'] = GetLastMinedBlockRIBSBSC
globals()['GetLastMinedBlockRIBSD'] = GetLastMinedBlockRIBSD
globals()['GetLastMinedBlockRIBSD2'] = GetLastMinedBlockRIBSD2
globals()['GetLastMinedBlockRIBSE'] = GetLastMinedBlockRIBSE
globals()['GetLastMinedBlockRIBSEC'] = GetLastMinedBlockRIBSEC
globals()['GetLastMinedBlockRIBSL'] = GetLastMinedBlockRIBSL
globals()['GetLastMinedBlockRIBSZ'] = GetLastMinedBlockRIBSZ
from cryptoapis.model.get_last_mined_block_ribs import GetLastMinedBlockRIBS


class TestGetLastMinedBlockRIBS(unittest.TestCase):
    """GetLastMinedBlockRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetLastMinedBlockRIBS(self):
        """Test GetLastMinedBlockRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetLastMinedBlockRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
