"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_confirmed_transactions_by_address_ribsd2_vout_inner_script_pub_key import ListConfirmedTransactionsByAddressRIBSD2VoutInnerScriptPubKey
globals()['ListConfirmedTransactionsByAddressRIBSD2VoutInnerScriptPubKey'] = ListConfirmedTransactionsByAddressRIBSD2VoutInnerScriptPubKey
from cryptoapis.model.list_confirmed_transactions_by_address_ribsd2_vout_inner import ListConfirmedTransactionsByAddressRIBSD2VoutInner


class TestListConfirmedTransactionsByAddressRIBSD2VoutInner(unittest.TestCase):
    """ListConfirmedTransactionsByAddressRIBSD2VoutInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListConfirmedTransactionsByAddressRIBSD2VoutInner(self):
        """Test ListConfirmedTransactionsByAddressRIBSD2VoutInner"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListConfirmedTransactionsByAddressRIBSD2VoutInner()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
