"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsb_vin_inner import GetTransactionDetailsByTransactionIDRIBSBVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsb_vout_inner import GetTransactionDetailsByTransactionIDRIBSBVoutInner
globals()['GetTransactionDetailsByTransactionIDRIBSBVinInner'] = GetTransactionDetailsByTransactionIDRIBSBVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSBVoutInner'] = GetTransactionDetailsByTransactionIDRIBSBVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsb import GetTransactionDetailsByTransactionIDRIBSB


class TestGetTransactionDetailsByTransactionIDRIBSB(unittest.TestCase):
    """GetTransactionDetailsByTransactionIDRIBSB unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTransactionDetailsByTransactionIDRIBSB(self):
        """Test GetTransactionDetailsByTransactionIDRIBSB"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTransactionDetailsByTransactionIDRIBSB()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
