"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_bep20 import AddressTokensTransactionConfirmedEachConfirmationBep20
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_erc20 import AddressTokensTransactionConfirmedEachConfirmationErc20
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_erc721 import AddressTokensTransactionConfirmedEachConfirmationErc721
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_omni import AddressTokensTransactionConfirmedEachConfirmationOmni
globals()['AddressTokensTransactionConfirmedEachConfirmationBep20'] = AddressTokensTransactionConfirmedEachConfirmationBep20
globals()['AddressTokensTransactionConfirmedEachConfirmationErc20'] = AddressTokensTransactionConfirmedEachConfirmationErc20
globals()['AddressTokensTransactionConfirmedEachConfirmationErc721'] = AddressTokensTransactionConfirmedEachConfirmationErc721
globals()['AddressTokensTransactionConfirmedEachConfirmationOmni'] = AddressTokensTransactionConfirmedEachConfirmationOmni
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_token import AddressTokensTransactionConfirmedEachConfirmationToken


class TestAddressTokensTransactionConfirmedEachConfirmationToken(unittest.TestCase):
    """AddressTokensTransactionConfirmedEachConfirmationToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddressTokensTransactionConfirmedEachConfirmationToken(self):
        """Test AddressTokensTransactionConfirmedEachConfirmationToken"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddressTokensTransactionConfirmedEachConfirmationToken()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
