"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.callback_data_api import CallbackDataApi  # noqa: E501


class TestCallbackDataApi(unittest.TestCase):
    """CallbackDataApi unit test stubs"""

    def setUp(self):
        self.api = CallbackDataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_address_details_from_callback(self):
        """Test case for get_address_details_from_callback

        Get Address Details From Callback  # noqa: E501
        """
        pass

    def test_get_block_details_by_block_hash_from_callback(self):
        """Test case for get_block_details_by_block_hash_from_callback

        Get Block Details By Block Hash From Callback  # noqa: E501
        """
        pass

    def test_get_block_details_by_block_height_from_callback(self):
        """Test case for get_block_details_by_block_height_from_callback

        Get Block Details By Block Height From Callback  # noqa: E501
        """
        pass

    def test_get_transaction_details_by_transaction_id_from_callback(self):
        """Test case for get_transaction_details_by_transaction_id_from_callback

        Get Transaction Details By Transaction ID From Callback  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
