"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_wallet_transactions_ri_fee import ListWalletTransactionsRIFee
from cryptoapis.model.list_wallet_transactions_ri_fungible_tokens_inner import ListWalletTransactionsRIFungibleTokensInner
from cryptoapis.model.list_wallet_transactions_ri_internal_transactions_inner import ListWalletTransactionsRIInternalTransactionsInner
from cryptoapis.model.list_wallet_transactions_ri_non_fungible_tokens_inner import ListWalletTransactionsRINonFungibleTokensInner
from cryptoapis.model.list_wallet_transactions_ri_recipients_inner import ListWalletTransactionsRIRecipientsInner
from cryptoapis.model.list_wallet_transactions_ri_senders_inner import ListWalletTransactionsRISendersInner
from cryptoapis.model.list_wallet_transactions_ri_value import ListWalletTransactionsRIValue
globals()['ListWalletTransactionsRIFee'] = ListWalletTransactionsRIFee
globals()['ListWalletTransactionsRIFungibleTokensInner'] = ListWalletTransactionsRIFungibleTokensInner
globals()['ListWalletTransactionsRIInternalTransactionsInner'] = ListWalletTransactionsRIInternalTransactionsInner
globals()['ListWalletTransactionsRINonFungibleTokensInner'] = ListWalletTransactionsRINonFungibleTokensInner
globals()['ListWalletTransactionsRIRecipientsInner'] = ListWalletTransactionsRIRecipientsInner
globals()['ListWalletTransactionsRISendersInner'] = ListWalletTransactionsRISendersInner
globals()['ListWalletTransactionsRIValue'] = ListWalletTransactionsRIValue
from cryptoapis.model.list_wallet_transactions_ri import ListWalletTransactionsRI


class TestListWalletTransactionsRI(unittest.TestCase):
    """ListWalletTransactionsRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListWalletTransactionsRI(self):
        """Test ListWalletTransactionsRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListWalletTransactionsRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
