"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.invalid_api_key import InvalidApiKey
from cryptoapis.model.missing_api_key import MissingApiKey
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['InvalidApiKey'] = InvalidApiKey
globals()['MissingApiKey'] = MissingApiKey
from cryptoapis.model.get_latest_mined_zilliqa_block_e401 import GetLatestMinedZilliqaBlockE401


class TestGetLatestMinedZilliqaBlockE401(unittest.TestCase):
    """GetLatestMinedZilliqaBlockE401 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetLatestMinedZilliqaBlockE401(self):
        """Test GetLatestMinedZilliqaBlockE401"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetLatestMinedZilliqaBlockE401()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
