"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.decode_raw_transaction_hex_risb import DecodeRawTransactionHexRISB
from cryptoapis.model.decode_raw_transaction_hex_risb2 import DecodeRawTransactionHexRISB2
from cryptoapis.model.decode_raw_transaction_hex_risb22 import DecodeRawTransactionHexRISB22
from cryptoapis.model.decode_raw_transaction_hex_risd import DecodeRawTransactionHexRISD
from cryptoapis.model.decode_raw_transaction_hex_risd2 import DecodeRawTransactionHexRISD2
from cryptoapis.model.decode_raw_transaction_hex_rise import DecodeRawTransactionHexRISE
from cryptoapis.model.decode_raw_transaction_hex_rise2 import DecodeRawTransactionHexRISE2
from cryptoapis.model.decode_raw_transaction_hex_risl import DecodeRawTransactionHexRISL
from cryptoapis.model.decode_raw_transaction_hex_risz import DecodeRawTransactionHexRISZ
from cryptoapis.model.decode_raw_transaction_hex_risz_vin_inner import DecodeRawTransactionHexRISZVinInner
from cryptoapis.model.decode_raw_transaction_hex_risz_vout_inner import DecodeRawTransactionHexRISZVoutInner
globals()['DecodeRawTransactionHexRISB'] = DecodeRawTransactionHexRISB
globals()['DecodeRawTransactionHexRISB2'] = DecodeRawTransactionHexRISB2
globals()['DecodeRawTransactionHexRISB22'] = DecodeRawTransactionHexRISB22
globals()['DecodeRawTransactionHexRISD'] = DecodeRawTransactionHexRISD
globals()['DecodeRawTransactionHexRISD2'] = DecodeRawTransactionHexRISD2
globals()['DecodeRawTransactionHexRISE'] = DecodeRawTransactionHexRISE
globals()['DecodeRawTransactionHexRISE2'] = DecodeRawTransactionHexRISE2
globals()['DecodeRawTransactionHexRISL'] = DecodeRawTransactionHexRISL
globals()['DecodeRawTransactionHexRISZ'] = DecodeRawTransactionHexRISZ
globals()['DecodeRawTransactionHexRISZVinInner'] = DecodeRawTransactionHexRISZVinInner
globals()['DecodeRawTransactionHexRISZVoutInner'] = DecodeRawTransactionHexRISZVoutInner
from cryptoapis.model.decode_raw_transaction_hex_ris import DecodeRawTransactionHexRIS


class TestDecodeRawTransactionHexRIS(unittest.TestCase):
    """DecodeRawTransactionHexRIS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDecodeRawTransactionHexRIS(self):
        """Test DecodeRawTransactionHexRIS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DecodeRawTransactionHexRIS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
