"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_automatic_coins_forwarding_e403 import CreateAutomaticCoinsForwardingE403
globals()['CreateAutomaticCoinsForwardingE403'] = CreateAutomaticCoinsForwardingE403
from cryptoapis.model.create_automatic_coins_forwarding403_response import CreateAutomaticCoinsForwarding403Response


class TestCreateAutomaticCoinsForwarding403Response(unittest.TestCase):
    """CreateAutomaticCoinsForwarding403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateAutomaticCoinsForwarding403Response(self):
        """Test CreateAutomaticCoinsForwarding403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateAutomaticCoinsForwarding403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
