"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.invalid_data import InvalidData
from cryptoapis.model.wallet_as_a_service_address_balance_not_enough import WalletAsAServiceAddressBalanceNotEnough
from cryptoapis.model.wallet_as_a_service_wallet_balance_not_enough import WalletAsAServiceWalletBalanceNotEnough
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['InvalidData'] = InvalidData
globals()['WalletAsAServiceAddressBalanceNotEnough'] = WalletAsAServiceAddressBalanceNotEnough
globals()['WalletAsAServiceWalletBalanceNotEnough'] = WalletAsAServiceWalletBalanceNotEnough
from cryptoapis.model.create_coins_transaction_request_from_address_e409 import CreateCoinsTransactionRequestFromAddressE409


class TestCreateCoinsTransactionRequestFromAddressE409(unittest.TestCase):
    """CreateCoinsTransactionRequestFromAddressE409 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCoinsTransactionRequestFromAddressE409(self):
        """Test CreateCoinsTransactionRequestFromAddressE409"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCoinsTransactionRequestFromAddressE409()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
