"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_asset_details_by_asset_idri_asset_logo import GetAssetDetailsByAssetIDRIAssetLogo
from cryptoapis.model.get_asset_details_by_asset_idri_latest_rate import GetAssetDetailsByAssetIDRILatestRate
from cryptoapis.model.get_asset_details_by_asset_idris import GetAssetDetailsByAssetIDRIS
globals()['GetAssetDetailsByAssetIDRIAssetLogo'] = GetAssetDetailsByAssetIDRIAssetLogo
globals()['GetAssetDetailsByAssetIDRILatestRate'] = GetAssetDetailsByAssetIDRILatestRate
globals()['GetAssetDetailsByAssetIDRIS'] = GetAssetDetailsByAssetIDRIS
from cryptoapis.model.get_asset_details_by_asset_idri import GetAssetDetailsByAssetIDRI


class TestGetAssetDetailsByAssetIDRI(unittest.TestCase):
    """GetAssetDetailsByAssetIDRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetAssetDetailsByAssetIDRI(self):
        """Test GetAssetDetailsByAssetIDRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetAssetDetailsByAssetIDRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
