"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.address_tokens_transaction_confirmed_bep20 import AddressTokensTransactionConfirmedBep20
from cryptoapis.model.address_tokens_transaction_confirmed_erc20 import AddressTokensTransactionConfirmedErc20
from cryptoapis.model.address_tokens_transaction_confirmed_erc721 import AddressTokensTransactionConfirmedErc721
from cryptoapis.model.address_tokens_transaction_confirmed_omni import AddressTokensTransactionConfirmedOmni
globals()['AddressTokensTransactionConfirmedBep20'] = AddressTokensTransactionConfirmedBep20
globals()['AddressTokensTransactionConfirmedErc20'] = AddressTokensTransactionConfirmedErc20
globals()['AddressTokensTransactionConfirmedErc721'] = AddressTokensTransactionConfirmedErc721
globals()['AddressTokensTransactionConfirmedOmni'] = AddressTokensTransactionConfirmedOmni
from cryptoapis.model.address_tokens_transaction_confirmed_token import AddressTokensTransactionConfirmedToken


class TestAddressTokensTransactionConfirmedToken(unittest.TestCase):
    """AddressTokensTransactionConfirmedToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddressTokensTransactionConfirmedToken(self):
        """Test AddressTokensTransactionConfirmedToken"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddressTokensTransactionConfirmedToken()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
