"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_ide400 import GetXRPRippleTransactionDetailsByTransactionIDE400
globals()['GetXRPRippleTransactionDetailsByTransactionIDE400'] = GetXRPRippleTransactionDetailsByTransactionIDE400
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_id400_response import GetXRPRippleTransactionDetailsByTransactionID400Response


class TestGetXRPRippleTransactionDetailsByTransactionID400Response(unittest.TestCase):
    """GetXRPRippleTransactionDetailsByTransactionID400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetXRPRippleTransactionDetailsByTransactionID400Response(self):
        """Test GetXRPRippleTransactionDetailsByTransactionID400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetXRPRippleTransactionDetailsByTransactionID400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
