"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_latest_mined_blocks_ribsb import ListLatestMinedBlocksRIBSB
from cryptoapis.model.list_latest_mined_blocks_ribsbc import ListLatestMinedBlocksRIBSBC
from cryptoapis.model.list_latest_mined_blocks_ribsbsc import ListLatestMinedBlocksRIBSBSC
from cryptoapis.model.list_latest_mined_blocks_ribsd import ListLatestMinedBlocksRIBSD
from cryptoapis.model.list_latest_mined_blocks_ribsd2 import ListLatestMinedBlocksRIBSD2
from cryptoapis.model.list_latest_mined_blocks_ribse import ListLatestMinedBlocksRIBSE
from cryptoapis.model.list_latest_mined_blocks_ribsec import ListLatestMinedBlocksRIBSEC
from cryptoapis.model.list_latest_mined_blocks_ribsl import ListLatestMinedBlocksRIBSL
from cryptoapis.model.list_latest_mined_blocks_ribsz import ListLatestMinedBlocksRIBSZ
from cryptoapis.model.list_latest_mined_blocks_ribsz2 import ListLatestMinedBlocksRIBSZ2
globals()['ListLatestMinedBlocksRIBSB'] = ListLatestMinedBlocksRIBSB
globals()['ListLatestMinedBlocksRIBSBC'] = ListLatestMinedBlocksRIBSBC
globals()['ListLatestMinedBlocksRIBSBSC'] = ListLatestMinedBlocksRIBSBSC
globals()['ListLatestMinedBlocksRIBSD'] = ListLatestMinedBlocksRIBSD
globals()['ListLatestMinedBlocksRIBSD2'] = ListLatestMinedBlocksRIBSD2
globals()['ListLatestMinedBlocksRIBSE'] = ListLatestMinedBlocksRIBSE
globals()['ListLatestMinedBlocksRIBSEC'] = ListLatestMinedBlocksRIBSEC
globals()['ListLatestMinedBlocksRIBSL'] = ListLatestMinedBlocksRIBSL
globals()['ListLatestMinedBlocksRIBSZ'] = ListLatestMinedBlocksRIBSZ
globals()['ListLatestMinedBlocksRIBSZ2'] = ListLatestMinedBlocksRIBSZ2
from cryptoapis.model.list_latest_mined_blocks_ribs import ListLatestMinedBlocksRIBS


class TestListLatestMinedBlocksRIBS(unittest.TestCase):
    """ListLatestMinedBlocksRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListLatestMinedBlocksRIBS(self):
        """Test ListLatestMinedBlocksRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListLatestMinedBlocksRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
