"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsb import ListConfirmedTransactionsByAddressAndTimeRangeRIBSB
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsbc import ListConfirmedTransactionsByAddressAndTimeRangeRIBSBC
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsbsc import ListConfirmedTransactionsByAddressAndTimeRangeRIBSBSC
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsd import ListConfirmedTransactionsByAddressAndTimeRangeRIBSD
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsd2 import ListConfirmedTransactionsByAddressAndTimeRangeRIBSD2
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribse import ListConfirmedTransactionsByAddressAndTimeRangeRIBSE
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsec import ListConfirmedTransactionsByAddressAndTimeRangeRIBSEC
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsl import ListConfirmedTransactionsByAddressAndTimeRangeRIBSL
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsz import ListConfirmedTransactionsByAddressAndTimeRangeRIBSZ
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc_gas_price import ListConfirmedTransactionsByAddressRIBSBSCGasPrice
from cryptoapis.model.list_confirmed_transactions_by_address_ribsz_vin_inner import ListConfirmedTransactionsByAddressRIBSZVinInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribszv_join_split_inner import ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSB'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSB
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSBC'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSBC
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSBSC'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSBSC
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSD'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSD
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSD2'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSD2
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSE'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSE
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSEC'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSEC
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSL'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSL
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSZ'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSZ
globals()['ListConfirmedTransactionsByAddressRIBSBSCGasPrice'] = ListConfirmedTransactionsByAddressRIBSBSCGasPrice
globals()['ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner'] = ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['ListConfirmedTransactionsByAddressRIBSZVinInner'] = ListConfirmedTransactionsByAddressRIBSZVinInner
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribs import ListConfirmedTransactionsByAddressAndTimeRangeRIBS


class TestListConfirmedTransactionsByAddressAndTimeRangeRIBS(unittest.TestCase):
    """ListConfirmedTransactionsByAddressAndTimeRangeRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListConfirmedTransactionsByAddressAndTimeRangeRIBS(self):
        """Test ListConfirmedTransactionsByAddressAndTimeRangeRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListConfirmedTransactionsByAddressAndTimeRangeRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
