"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_zilliqa_address_details_e403 import GetZilliqaAddressDetailsE403
globals()['GetZilliqaAddressDetailsE403'] = GetZilliqaAddressDetailsE403
from cryptoapis.model.get_zilliqa_address_details403_response import GetZilliqaAddressDetails403Response


class TestGetZilliqaAddressDetails403Response(unittest.TestCase):
    """GetZilliqaAddressDetails403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetZilliqaAddressDetails403Response(self):
        """Test GetZilliqaAddressDetails403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetZilliqaAddressDetails403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
