"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_transactions_by_block_height_ribsz_vin_inner import ListTransactionsByBlockHeightRIBSZVinInner
from cryptoapis.model.list_transactions_by_block_height_ribsz_vout_inner import ListTransactionsByBlockHeightRIBSZVoutInner
from cryptoapis.model.list_transactions_by_block_height_ribszv_join_split_inner import ListTransactionsByBlockHeightRIBSZVJoinSplitInner
from cryptoapis.model.list_transactions_by_block_height_ribszv_shielded_output_inner import ListTransactionsByBlockHeightRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['ListTransactionsByBlockHeightRIBSZVJoinSplitInner'] = ListTransactionsByBlockHeightRIBSZVJoinSplitInner
globals()['ListTransactionsByBlockHeightRIBSZVShieldedOutputInner'] = ListTransactionsByBlockHeightRIBSZVShieldedOutputInner
globals()['ListTransactionsByBlockHeightRIBSZVinInner'] = ListTransactionsByBlockHeightRIBSZVinInner
globals()['ListTransactionsByBlockHeightRIBSZVoutInner'] = ListTransactionsByBlockHeightRIBSZVoutInner
from cryptoapis.model.list_transactions_by_block_height_ribsz import ListTransactionsByBlockHeightRIBSZ


class TestListTransactionsByBlockHeightRIBSZ(unittest.TestCase):
    """ListTransactionsByBlockHeightRIBSZ unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHeightRIBSZ(self):
        """Test ListTransactionsByBlockHeightRIBSZ"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHeightRIBSZ()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
