"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address_e401 import CreateFungibleTokensTransactionRequestFromAddressE401
globals()['CreateFungibleTokensTransactionRequestFromAddressE401'] = CreateFungibleTokensTransactionRequestFromAddressE401
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address401_response import CreateFungibleTokensTransactionRequestFromAddress401Response


class TestCreateFungibleTokensTransactionRequestFromAddress401Response(unittest.TestCase):
    """CreateFungibleTokensTransactionRequestFromAddress401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateFungibleTokensTransactionRequestFromAddress401Response(self):
        """Test CreateFungibleTokensTransactionRequestFromAddress401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateFungibleTokensTransactionRequestFromAddress401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
