"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vin_inner import GetTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_all_unconfirmed_transactions_ribsb import ListAllUnconfirmedTransactionsRIBSB
from cryptoapis.model.list_all_unconfirmed_transactions_ribsbc import ListAllUnconfirmedTransactionsRIBSBC
from cryptoapis.model.list_all_unconfirmed_transactions_ribsbsc import ListAllUnconfirmedTransactionsRIBSBSC
from cryptoapis.model.list_all_unconfirmed_transactions_ribsd import ListAllUnconfirmedTransactionsRIBSD
from cryptoapis.model.list_all_unconfirmed_transactions_ribsd2 import ListAllUnconfirmedTransactionsRIBSD2
from cryptoapis.model.list_all_unconfirmed_transactions_ribse import ListAllUnconfirmedTransactionsRIBSE
from cryptoapis.model.list_all_unconfirmed_transactions_ribsec import ListAllUnconfirmedTransactionsRIBSEC
from cryptoapis.model.list_all_unconfirmed_transactions_ribsec_fee import ListAllUnconfirmedTransactionsRIBSECFee
from cryptoapis.model.list_all_unconfirmed_transactions_ribsl import ListAllUnconfirmedTransactionsRIBSL
from cryptoapis.model.list_all_unconfirmed_transactions_ribsz import ListAllUnconfirmedTransactionsRIBSZ
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc_gas_price import ListConfirmedTransactionsByAddressRIBSBSCGasPrice
from cryptoapis.model.list_confirmed_transactions_by_address_ribszv_join_split_inner import ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVinInner'] = GetTransactionDetailsByTransactionIDRIBSZVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListAllUnconfirmedTransactionsRIBSB'] = ListAllUnconfirmedTransactionsRIBSB
globals()['ListAllUnconfirmedTransactionsRIBSBC'] = ListAllUnconfirmedTransactionsRIBSBC
globals()['ListAllUnconfirmedTransactionsRIBSBSC'] = ListAllUnconfirmedTransactionsRIBSBSC
globals()['ListAllUnconfirmedTransactionsRIBSD'] = ListAllUnconfirmedTransactionsRIBSD
globals()['ListAllUnconfirmedTransactionsRIBSD2'] = ListAllUnconfirmedTransactionsRIBSD2
globals()['ListAllUnconfirmedTransactionsRIBSE'] = ListAllUnconfirmedTransactionsRIBSE
globals()['ListAllUnconfirmedTransactionsRIBSEC'] = ListAllUnconfirmedTransactionsRIBSEC
globals()['ListAllUnconfirmedTransactionsRIBSECFee'] = ListAllUnconfirmedTransactionsRIBSECFee
globals()['ListAllUnconfirmedTransactionsRIBSL'] = ListAllUnconfirmedTransactionsRIBSL
globals()['ListAllUnconfirmedTransactionsRIBSZ'] = ListAllUnconfirmedTransactionsRIBSZ
globals()['ListConfirmedTransactionsByAddressRIBSBSCGasPrice'] = ListConfirmedTransactionsByAddressRIBSBSCGasPrice
globals()['ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner'] = ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
from cryptoapis.model.list_all_unconfirmed_transactions_ribs import ListAllUnconfirmedTransactionsRIBS


class TestListAllUnconfirmedTransactionsRIBS(unittest.TestCase):
    """ListAllUnconfirmedTransactionsRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListAllUnconfirmedTransactionsRIBS(self):
        """Test ListAllUnconfirmedTransactionsRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListAllUnconfirmedTransactionsRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
