"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_hd_wallet_x_pub_y_pub_z_pub_assets_e401 import GetHDWalletXPubYPubZPubAssetsE401
globals()['GetHDWalletXPubYPubZPubAssetsE401'] = GetHDWalletXPubYPubZPubAssetsE401
from cryptoapis.model.get_hd_wallet_x_pub_y_pub_z_pub_assets401_response import GetHDWalletXPubYPubZPubAssets401Response


class TestGetHDWalletXPubYPubZPubAssets401Response(unittest.TestCase):
    """GetHDWalletXPubYPubZPubAssets401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetHDWalletXPubYPubZPubAssets401Response(self):
        """Test GetHDWalletXPubYPubZPubAssets401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetHDWalletXPubYPubZPubAssets401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
