"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.could_not_calculate_rate_for_pair import CouldNotCalculateRateForPair
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['CouldNotCalculateRateForPair'] = CouldNotCalculateRateForPair
globals()['InvalidRequestBodyStructure'] = InvalidRequestBodyStructure
from cryptoapis.model.get_exchange_rate_by_asset_symbols_e422 import GetExchangeRateByAssetSymbolsE422


class TestGetExchangeRateByAssetSymbolsE422(unittest.TestCase):
    """GetExchangeRateByAssetSymbolsE422 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetExchangeRateByAssetSymbolsE422(self):
        """Test GetExchangeRateByAssetSymbolsE422"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetExchangeRateByAssetSymbolsE422()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
