"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.invalid_pagination import InvalidPagination
from cryptoapis.model.limit_greater_than_allowed import LimitGreaterThanAllowed
from cryptoapis.model.uri_not_found import UriNotFound
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['InvalidPagination'] = InvalidPagination
globals()['LimitGreaterThanAllowed'] = LimitGreaterThanAllowed
globals()['UriNotFound'] = UriNotFound
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_e400 import NewConfirmedTokensTransactionsAndEachConfirmationE400


class TestNewConfirmedTokensTransactionsAndEachConfirmationE400(unittest.TestCase):
    """NewConfirmedTokensTransactionsAndEachConfirmationE400 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNewConfirmedTokensTransactionsAndEachConfirmationE400(self):
        """Test NewConfirmedTokensTransactionsAndEachConfirmationE400"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NewConfirmedTokensTransactionsAndEachConfirmationE400()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
