"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
from cryptoapis.model.xpub_sync_in_progress import XpubSyncInProgress
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['InvalidRequestBodyStructure'] = InvalidRequestBodyStructure
globals()['XpubSyncInProgress'] = XpubSyncInProgress
from cryptoapis.model.sync_hd_wallet_x_pub_y_pub_z_pub_e422 import SyncHDWalletXPubYPubZPubE422


class TestSyncHDWalletXPubYPubZPubE422(unittest.TestCase):
    """SyncHDWalletXPubYPubZPubE422 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSyncHDWalletXPubYPubZPubE422(self):
        """Test SyncHDWalletXPubYPubZPubE422"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SyncHDWalletXPubYPubZPubE422()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
