"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.features_api import FeaturesApi  # noqa: E501


class TestFeaturesApi(unittest.TestCase):
    """FeaturesApi unit test stubs"""

    def setUp(self):
        self.api = FeaturesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_broadcast_locally_signed_transaction(self):
        """Test case for broadcast_locally_signed_transaction

        Broadcast Locally Signed Transaction  # noqa: E501
        """
        pass

    def test_decode_raw_transaction_hex(self):
        """Test case for decode_raw_transaction_hex

        Decode Raw Transaction Hex  # noqa: E501
        """
        pass

    def test_decode_x_address(self):
        """Test case for decode_x_address

        Decode X-Address  # noqa: E501
        """
        pass

    def test_derive_hd_wallet__x_pub_y_pub_z_pub_change_or_receiving_addresses(self):
        """Test case for derive_hd_wallet__x_pub_y_pub_z_pub_change_or_receiving_addresses

        Derive HD Wallet (xPub, yPub, zPub) Change Or Receiving Addresses  # noqa: E501
        """
        pass

    def test_encode_x_address(self):
        """Test case for encode_x_address

        Encode X-Address  # noqa: E501
        """
        pass

    def test_estimate_gas_limit(self):
        """Test case for estimate_gas_limit

        Estimate Gas Limit  # noqa: E501
        """
        pass

    def test_estimate_token_gas_limit(self):
        """Test case for estimate_token_gas_limit

        Estimate Token Gas Limit  # noqa: E501
        """
        pass

    def test_get_eip_1559_fee_recommendations(self):
        """Test case for get_eip_1559_fee_recommendations

        Get EIP 1559 Fee Recommendations  # noqa: E501
        """
        pass

    def test_validate_address(self):
        """Test case for validate_address

        Validate Address  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
