"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.confirmed_tokens_transaction_for_certain_amount_or_higher_bep20 import ConfirmedTokensTransactionForCertainAmountOrHigherBep20
from cryptoapis.model.confirmed_tokens_transaction_for_certain_amount_or_higher_erc20 import ConfirmedTokensTransactionForCertainAmountOrHigherErc20
from cryptoapis.model.confirmed_tokens_transaction_for_certain_amount_or_higher_erc721 import ConfirmedTokensTransactionForCertainAmountOrHigherErc721
globals()['ConfirmedTokensTransactionForCertainAmountOrHigherBep20'] = ConfirmedTokensTransactionForCertainAmountOrHigherBep20
globals()['ConfirmedTokensTransactionForCertainAmountOrHigherErc20'] = ConfirmedTokensTransactionForCertainAmountOrHigherErc20
globals()['ConfirmedTokensTransactionForCertainAmountOrHigherErc721'] = ConfirmedTokensTransactionForCertainAmountOrHigherErc721
from cryptoapis.model.confirmed_tokens_transaction_for_certain_amount_or_higher_token import ConfirmedTokensTransactionForCertainAmountOrHigherToken


class TestConfirmedTokensTransactionForCertainAmountOrHigherToken(unittest.TestCase):
    """ConfirmedTokensTransactionForCertainAmountOrHigherToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConfirmedTokensTransactionForCertainAmountOrHigherToken(self):
        """Test ConfirmedTokensTransactionForCertainAmountOrHigherToken"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConfirmedTokensTransactionForCertainAmountOrHigherToken()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
