"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address import BannedIpAddress
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.endpoint_not_allowed_for_api_key import EndpointNotAllowedForApiKey
from cryptoapis.model.endpoint_not_allowed_for_plan import EndpointNotAllowedForPlan
from cryptoapis.model.feature_mainnets_not_allowed_for_plan import FeatureMainnetsNotAllowedForPlan
globals()['BannedIpAddress'] = BannedIpAddress
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['EndpointNotAllowedForApiKey'] = EndpointNotAllowedForApiKey
globals()['EndpointNotAllowedForPlan'] = EndpointNotAllowedForPlan
globals()['FeatureMainnetsNotAllowedForPlan'] = FeatureMainnetsNotAllowedForPlan
from cryptoapis.model.create_coins_transaction_request_from_address_e403 import CreateCoinsTransactionRequestFromAddressE403


class TestCreateCoinsTransactionRequestFromAddressE403(unittest.TestCase):
    """CreateCoinsTransactionRequestFromAddressE403 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCoinsTransactionRequestFromAddressE403(self):
        """Test CreateCoinsTransactionRequestFromAddressE403"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCoinsTransactionRequestFromAddressE403()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
