"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsb import GetTransactionDetailsByTransactionIDRIBSB
from cryptoapis.model.get_transaction_details_by_transaction_idribsbc import GetTransactionDetailsByTransactionIDRIBSBC
from cryptoapis.model.get_transaction_details_by_transaction_idribsbsc import GetTransactionDetailsByTransactionIDRIBSBSC
from cryptoapis.model.get_transaction_details_by_transaction_idribsbsc_gas_price import GetTransactionDetailsByTransactionIDRIBSBSCGasPrice
from cryptoapis.model.get_transaction_details_by_transaction_idribsd import GetTransactionDetailsByTransactionIDRIBSD
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2 import GetTransactionDetailsByTransactionIDRIBSD2
from cryptoapis.model.get_transaction_details_by_transaction_idribse import GetTransactionDetailsByTransactionIDRIBSE
from cryptoapis.model.get_transaction_details_by_transaction_idribsec import GetTransactionDetailsByTransactionIDRIBSEC
from cryptoapis.model.get_transaction_details_by_transaction_idribsl import GetTransactionDetailsByTransactionIDRIBSL
from cryptoapis.model.get_transaction_details_by_transaction_idribsz import GetTransactionDetailsByTransactionIDRIBSZ
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vin_inner import GetTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_join_split_inner import GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSB'] = GetTransactionDetailsByTransactionIDRIBSB
globals()['GetTransactionDetailsByTransactionIDRIBSBC'] = GetTransactionDetailsByTransactionIDRIBSBC
globals()['GetTransactionDetailsByTransactionIDRIBSBSC'] = GetTransactionDetailsByTransactionIDRIBSBSC
globals()['GetTransactionDetailsByTransactionIDRIBSBSCGasPrice'] = GetTransactionDetailsByTransactionIDRIBSBSCGasPrice
globals()['GetTransactionDetailsByTransactionIDRIBSD'] = GetTransactionDetailsByTransactionIDRIBSD
globals()['GetTransactionDetailsByTransactionIDRIBSD2'] = GetTransactionDetailsByTransactionIDRIBSD2
globals()['GetTransactionDetailsByTransactionIDRIBSE'] = GetTransactionDetailsByTransactionIDRIBSE
globals()['GetTransactionDetailsByTransactionIDRIBSEC'] = GetTransactionDetailsByTransactionIDRIBSEC
globals()['GetTransactionDetailsByTransactionIDRIBSL'] = GetTransactionDetailsByTransactionIDRIBSL
globals()['GetTransactionDetailsByTransactionIDRIBSZ'] = GetTransactionDetailsByTransactionIDRIBSZ
globals()['GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner'] = GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVinInner'] = GetTransactionDetailsByTransactionIDRIBSZVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribs import GetTransactionDetailsByTransactionIDRIBS


class TestGetTransactionDetailsByTransactionIDRIBS(unittest.TestCase):
    """GetTransactionDetailsByTransactionIDRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTransactionDetailsByTransactionIDRIBS(self):
        """Test GetTransactionDetailsByTransactionIDRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTransactionDetailsByTransactionIDRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
